# Python SDK for the Invoicetronic API

The [Invoicetronic API][2] is a RESTful service that allows you to send and receive invoices through the Italian [Servizio di Interscambio (SDI)][1], or Interchange Service. The API is designed to be simple and easy to use, abstracting away SDI complexity while providing complete control over the invoice send/receive process. It provides advanced features as encryption at rest, multi-language pre-flight invoice validation, multiple upload formats, webhooks, event logging, client SDKs, and CLI tools.

For more information, see  [Invoicetronic website][2]

[1]: https://www.fatturapa.gov.it/it/sistemainterscambio/cose-il-sdi/
[2]: https://invoicetronic.com/

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1
- Package version: 1.0.0
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://invoicetronic.com](https://invoicetronic.com)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/invoicetronic/python-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/invoicetronic/python-sdk.git`)

Then import the package:
```python
import invoicetronic_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import invoicetronic_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import invoicetronic_sdk
from invoicetronic_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.invoicetronic.com
# See configuration.py for a list of all supported configuration parameters.
configuration = invoicetronic_sdk.Configuration(
    host = "https://api.invoicetronic.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: Basic
configuration = invoicetronic_sdk.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)


# Enter a context with an instance of the API client
with invoicetronic_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = invoicetronic_sdk.CompanyApi(api_client)
    page = 1 # int | Page number. (optional) (default to 1)
    page_size = 100 # int | Items per page. Cannot be greater than 200. (optional) (default to 100)
    sort = 'sort_example' # str | Sort by field. Prefix with '-' for descending order. (optional)

    try:
        # List companies
        api_response = api_instance.company_get(page=page, page_size=page_size, sort=sort)
        print("The response of CompanyApi->company_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CompanyApi->company_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompanyApi* | [**company_get**](docs/CompanyApi.md#company_get) | **GET** /company | List companies
*CompanyApi* | [**company_id_delete**](docs/CompanyApi.md#company_id_delete) | **DELETE** /company/{id} | Delete a company
*CompanyApi* | [**company_id_get**](docs/CompanyApi.md#company_id_get) | **GET** /company/{id} | Get a company by id
*CompanyApi* | [**company_post**](docs/CompanyApi.md#company_post) | **POST** /company | Add a company
*CompanyApi* | [**company_put**](docs/CompanyApi.md#company_put) | **PUT** /company | Update a company
*LogApi* | [**log_get**](docs/LogApi.md#log_get) | **GET** /log | List events
*LogApi* | [**log_id_get**](docs/LogApi.md#log_id_get) | **GET** /log/{id} | Get an event by id
*ReceiveApi* | [**receive_get**](docs/ReceiveApi.md#receive_get) | **GET** /receive | List incoming invoices
*ReceiveApi* | [**receive_id_delete**](docs/ReceiveApi.md#receive_id_delete) | **DELETE** /receive/{id} | Delete an incoming invoice by id
*ReceiveApi* | [**receive_id_get**](docs/ReceiveApi.md#receive_id_get) | **GET** /receive/{id} | Get an incoming invoice by id
*SendApi* | [**send_file_post**](docs/SendApi.md#send_file_post) | **POST** /send/file | Add an invoice by file
*SendApi* | [**send_get**](docs/SendApi.md#send_get) | **GET** /send | List invoices
*SendApi* | [**send_id_get**](docs/SendApi.md#send_id_get) | **GET** /send/{id} | Get a invoice by id
*SendApi* | [**send_identifier_get**](docs/SendApi.md#send_identifier_get) | **GET** /send/{identifier} | Get a invoice by identifier
*SendApi* | [**send_json_post**](docs/SendApi.md#send_json_post) | **POST** /send/json | Add an invoice by json
*SendApi* | [**send_post**](docs/SendApi.md#send_post) | **POST** /send | Add an invoice
*SendApi* | [**send_validate_file_post**](docs/SendApi.md#send_validate_file_post) | **POST** /send/validate/file | Validate an invoice file
*SendApi* | [**send_validate_json_post**](docs/SendApi.md#send_validate_json_post) | **POST** /send/validate/json | Validate an invoice by json
*SendApi* | [**send_validate_post**](docs/SendApi.md#send_validate_post) | **POST** /send/validate | Validate an invoice
*SendApi* | [**send_validate_xml_post**](docs/SendApi.md#send_validate_xml_post) | **POST** /send/validate/xml | Validate an invoice by xml
*SendApi* | [**send_xml_post**](docs/SendApi.md#send_xml_post) | **POST** /send/xml | Add an invoice by xml
*StatusApi* | [**status_get**](docs/StatusApi.md#status_get) | **GET** /status | Account status
*UpdateApi* | [**update_get**](docs/UpdateApi.md#update_get) | **GET** /update | List updates
*UpdateApi* | [**update_id_get**](docs/UpdateApi.md#update_id_get) | **GET** /update/{id} | Get an update by id
*WebhookApi* | [**webhook_get**](docs/WebhookApi.md#webhook_get) | **GET** /webhook | List webhooks
*WebhookApi* | [**webhook_id_delete**](docs/WebhookApi.md#webhook_id_delete) | **DELETE** /webhook/{id} | Delete a webhook by id
*WebhookApi* | [**webhook_id_get**](docs/WebhookApi.md#webhook_id_get) | **GET** /webhook/{id} | Get a webhook by id
*WebhookApi* | [**webhook_post**](docs/WebhookApi.md#webhook_post) | **POST** /webhook | Add a webhook
*WebhookApi* | [**webhook_put**](docs/WebhookApi.md#webhook_put) | **PUT** /webhook | Update a webhook
*WebhookApi* | [**webhookhistory_get**](docs/WebhookApi.md#webhookhistory_get) | **GET** /webhookhistory | List webhook history items
*WebhookApi* | [**webhookhistory_id_get**](docs/WebhookApi.md#webhookhistory_id_get) | **GET** /webhookhistory/{id} | Get a webhook history item by id


## Documentation For Models

 - [Allegati](docs/Allegati.md)
 - [AltriDatiGestionali](docs/AltriDatiGestionali.md)
 - [Anagrafica](docs/Anagrafica.md)
 - [CedentePrestatore](docs/CedentePrestatore.md)
 - [CessionarioCommittente](docs/CessionarioCommittente.md)
 - [CodiceArticolo](docs/CodiceArticolo.md)
 - [Company](docs/Company.md)
 - [Contatti](docs/Contatti.md)
 - [ContattiTrasmittente](docs/ContattiTrasmittente.md)
 - [DatiAnagrafici](docs/DatiAnagrafici.md)
 - [DatiAnagraficiCedentePrestatore](docs/DatiAnagraficiCedentePrestatore.md)
 - [DatiAnagraficiCessionarioCommittente](docs/DatiAnagraficiCessionarioCommittente.md)
 - [DatiAnagraficiVettore](docs/DatiAnagraficiVettore.md)
 - [DatiBeniServizi](docs/DatiBeniServizi.md)
 - [DatiBollo](docs/DatiBollo.md)
 - [DatiCassaPrevidenziale](docs/DatiCassaPrevidenziale.md)
 - [DatiContratto](docs/DatiContratto.md)
 - [DatiConvenzione](docs/DatiConvenzione.md)
 - [DatiDDT](docs/DatiDDT.md)
 - [DatiFattureCollegate](docs/DatiFattureCollegate.md)
 - [DatiGenerali](docs/DatiGenerali.md)
 - [DatiGeneraliDocumento](docs/DatiGeneraliDocumento.md)
 - [DatiOrdineAcquisto](docs/DatiOrdineAcquisto.md)
 - [DatiPagamento](docs/DatiPagamento.md)
 - [DatiRicezione](docs/DatiRicezione.md)
 - [DatiRiepilogo](docs/DatiRiepilogo.md)
 - [DatiRitenuta](docs/DatiRitenuta.md)
 - [DatiSAL](docs/DatiSAL.md)
 - [DatiTrasmissione](docs/DatiTrasmissione.md)
 - [DatiTrasporto](docs/DatiTrasporto.md)
 - [DatiVeicoli](docs/DatiVeicoli.md)
 - [DettaglioLinee](docs/DettaglioLinee.md)
 - [DettaglioPagamento](docs/DettaglioPagamento.md)
 - [DocumentData](docs/DocumentData.md)
 - [Error](docs/Error.md)
 - [Event](docs/Event.md)
 - [FatturaElettronicaBody](docs/FatturaElettronicaBody.md)
 - [FatturaElettronicaHeader](docs/FatturaElettronicaHeader.md)
 - [FatturaOrdinaria](docs/FatturaOrdinaria.md)
 - [FatturaPrincipale](docs/FatturaPrincipale.md)
 - [IdFiscaleIVA](docs/IdFiscaleIVA.md)
 - [IdTrasmittente](docs/IdTrasmittente.md)
 - [IndirizzoResa](docs/IndirizzoResa.md)
 - [IscrizioneREA](docs/IscrizioneREA.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [ProblemHttpResult](docs/ProblemHttpResult.md)
 - [RappresentanteFiscale](docs/RappresentanteFiscale.md)
 - [RappresentanteFiscaleCessionarioCommittente](docs/RappresentanteFiscaleCessionarioCommittente.md)
 - [Receive](docs/Receive.md)
 - [ScontoMaggiorazione](docs/ScontoMaggiorazione.md)
 - [SedeCedentePrestatore](docs/SedeCedentePrestatore.md)
 - [SedeCessionarioCommittente](docs/SedeCessionarioCommittente.md)
 - [Send](docs/Send.md)
 - [SendReduced](docs/SendReduced.md)
 - [StabileOrganizzazione](docs/StabileOrganizzazione.md)
 - [Status](docs/Status.md)
 - [TerzoIntermediarioOSoggettoEmittente](docs/TerzoIntermediarioOSoggettoEmittente.md)
 - [Update](docs/Update.md)
 - [WebHook](docs/WebHook.md)
 - [WebHookHistory](docs/WebHookHistory.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Basic"></a>
### Basic

- **Type**: HTTP basic authentication


## Author

info@invoicetronic.com


